Module: Textoken::RegexpOption
- Includes:
- ConditionalOption
- Included in:
- ExcludeRegexp, OnlyRegexp
- Defined in:
- lib/textoken/options/modules/regexp_option.rb
Overview
This module will be shared in options like, only_regexp and exclude_regexp
This module will be shared in options like, only_regexp and exclude_regexp